==> dojo-1.9.4.tgz: package/cldr/nls/ko/chinese.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yyyyMMMEd": "U년 MMM d일 (E)",
	"field-dayperiod": "오전/오후",
	"field-minute": "분",
	"dateFormatItem-MMMEd": "MMM d일 (E)",
	"field-day-relative+-1": "어제",
	"dateFormatItem-hms": "a h:mm:ss",
	"field-day-relative+-2": "그저께",
	"field-weekday": "요일",
	"dateFormatItem-MMM": "LLL",
	"dateFormatItem-Gy": "U년",
	"field-era": "연호",
	"field-hour": "시",
	"dateFormatItem-y": "U년",
	"dateFormatItem-yyyy": "U년",
	"dateFormatItem-yyyyMMMEEEEd": "U년 MMM d일 EEEE",
	"dateFormatItem-EEEEd": "d일 EEEE",
	"dateFormatItem-Ed": "d일 (E)",
	"field-day-relative+0": "오늘",
	"field-day-relative+1": "내일",
	"field-day-relative+2": "모레",
	"dateFormatItem-GyMMMd": "U년 MMM d일",
	"dateFormat-long": "U년 M월 d일",
	"field-zone": "시간대",
	"dateFormatItem-MMMEEEEd": "MMM d일 EEEE",
	"field-week-relative+-1": "지난주",
	"dateFormat-medium": "y. M. d.",
	"dateFormatItem-Hms": "H시 m분 s초",
	"field-year-relative+0": "올해",
	"field-year-relative+1": "내년",
	"dateFormatItem-yMd": "U. M. d.",
	"field-year-relative+-1": "지난해",
	"dateFormatItem-yyyyQQQQ": "U년 QQQQ",
	"field-year": "년",
	"dateFormatItem-GyMMMEEEEd": "U년 MMM d일 EEEE",
	"field-week": "주",
	"dateFormatItem-yyyyMd": "U. M. d.",
	"dateFormatItem-yyyyMMMd": "U년 MMM d일",
	"dateFormatItem-yyyyMEd": "U. M. d. (E)",
	"dateFormatItem-yyyyMEEEEd": "U. M. d. EEEE",
	"dateFormatItem-MMMd": "MMM d일",
	"field-week-relative+0": "이번 주",
	"field-week-relative+1": "다음 주",
	"field-month-relative+0": "이번 달",
	"dateFormatItem-H": "H시",
	"field-month": "월",
	"field-month-relative+1": "다음 달",
	"dateFormatItem-M": "M월",
	"field-second": "초",
	"dateFormatItem-GyMMMEd": "U년 MMM d일 (E)",
	"dateFormatItem-GyMMM": "U년 MMM",
	"dateFormatItem-MEEEEd": "M. d. EEEE",
	"field-day": "일",
	"dateFormatItem-MEd": "M. d. (E)",
	"dateFormatItem-yyyyQQQ": "U년 QQQ",
	"dateFormatItem-hm": "a h:mm",
	"dateFormat-short": "y. M. d.",
	"dateFormatItem-yyyyM": "U. M.",
	"dateFormat-full": "U년 M월 d일 EEEE",
	"dateFormatItem-Md": "M. d.",
	"dateFormatItem-yyyyMMM": "U년 MMM",
	"dateFormatItem-d": "d일",
	"field-month-relative+-1": "지난달",
	"dateFormatItem-h": "a h시"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/ko/chinese.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "지금",
	"field-weekday": "요일",
	"field-wed-relative+0": "이번 수요일",
	"field-wed-relative+1": "다음 수요일",
	"dateFormatItem-GyMMMEd": "U년 MMM d일 (E)",
	"dateFormatItem-MMMEd": "MMM d일 (E)",
	"field-tue-relative+-1": "지난 화요일",
	"dateFormat-long": "U년 MMM d일",
	"field-fri-relative+-1": "지난 금요일",
	"field-wed-relative+-1": "지난 수요일",
	"dateFormatItem-yyyyQQQ": "U년 QQQ",
	"dateFormat-full": "U년 MMM d일 EEEE",
	"dateFormatItem-yyyyMEd": "U. M. d. (E)",
	"field-thu-relative+-1": "지난 목요일",
	"dateFormatItem-Md": "M. d.",
	"dateFormatItem-yMd": "U. M. d.",
	"field-era": "연호",
	"dateFormatItem-MEEEEd": "M. d. EEEE",
	"field-year": "년",
	"field-hour": "시",
	"field-sat-relative+0": "이번 토요일",
	"field-sat-relative+1": "다음 토요일",
	"field-day-relative+0": "오늘",
	"field-day-relative+1": "내일",
	"field-thu-relative+0": "이번 목요일",
	"dateFormatItem-GyMMMd": "U년 MMM d일",
	"field-day-relative+2": "모레",
	"field-thu-relative+1": "다음 목요일",
	"dateFormatItem-H": "H시",
	"dateFormatItem-Gy": "U년",
	"dateFormatItem-yyyyMMMEd": "U년 MMM d일 (E)",
	"dateFormatItem-M": "MMM",
	"dateFormatItem-yyyyMMM": "U년 MMM",
	"dateFormatItem-yyyyMMMd": "U년 MMM d일",
	"field-sun-relative+0": "이번 일요일",
	"field-sun-relative+1": "다음 일요일",
	"field-minute": "분",
	"field-dayperiod": "오전/오후",
	"dateFormatItem-d": "d일",
	"dateFormatItem-yyyyMEEEEd": "U. M. d. EEEE",
	"field-day-relative+-1": "어제",
	"dateFormatItem-h": "a h시",
	"field-day-relative+-2": "그저께",
	"dateFormatItem-MMMd": "MMM d일",
	"dateFormatItem-EEEEd": "d일 EEEE",
	"dateFormatItem-MEd": "M. d. (E)",
	"field-fri-relative+0": "이번 금요일",
	"field-fri-relative+1": "다음 금요일",
	"field-day": "일",
	"field-zone": "시간대",
	"dateFormatItem-y": "U년",
	"field-year-relative+-1": "작년",
	"field-month-relative+-1": "지난달",
	"dateFormatItem-hm": "a h:mm",
	"dateFormatItem-GyMMMEEEEd": "U년 MMM d일 EEEE",
	"dateFormatItem-yyyyMMMEEEEd": "U년 MMM d일 EEEE",
	"dateFormatItem-MMMEEEEd": "MMM d일 EEEE",
	"dateFormatItem-yyyyMd": "U. M. d.",
	"field-month": "월",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "이번 화요일",
	"field-tue-relative+1": "다음 화요일",
	"field-mon-relative+0": "이번 월요일",
	"field-mon-relative+1": "다음 월요일",
	"dateFormat-short": "y. M. d.",
	"field-second": "초",
	"field-sat-relative+-1": "지난 토요일",
	"field-sun-relative+-1": "지난 일요일",
	"field-month-relative+0": "이번 달",
	"field-month-relative+1": "다음 달",
	"dateFormatItem-Ed": "d일 (E)",
	"field-week": "주",
	"dateFormat-medium": "y. M. d.",
	"field-year-relative+0": "올해",
	"field-week-relative+-1": "지난주",
	"dateFormatItem-yyyyM": "U. M.",
	"field-year-relative+1": "내년",
	"dateFormatItem-yyyyQQQQ": "U년 QQQQ",
	"dateFormatItem-Hms": "H시 m분 s초",
	"dateFormatItem-hms": "a h:mm:ss",
	"dateFormatItem-GyMMM": "U년 MMM",
	"field-mon-relative+-1": "지난 월요일",
	"dateFormatItem-yyyy": "U년",
	"field-week-relative+0": "이번 주",
	"field-week-relative+1": "다음 주"
}
//end v1.x content
);
